@@ -27,7 +27,7 @@ use File::Basename;
 use Time::Piece;
 use Text::TabularDisplay;
 
-our @EXPORT_OK = qw(prompt db updaterecord deleterecord newrecord notimplemented nocommand nosubcommand listchoices lookupval lookuplist today validate ini printlist round pad lookupcol thin resolvenegid chooseneg annotatefilm keyword parselensmodel unsetdisplaylens welcome duration tag printbool hashdiff logger now choosescan basepath call untaint fsfiles dbfiles term unsci multiplechoice search tabulate runmigrations canondatecode);
+our @EXPORT_OK = qw(prompt db updaterecord deleterecord newrecord notimplemented nocommand nosubcommand listchoices lookupval lookuplist today validate ini printlist round pad lookupcol thin resolvenegid chooseneg annotatefilm keyword parselensmodel unsetdisplaylens welcome duration tag printbool hashdiff logger now choosescan basepath call untaint fsfiles dbfiles term unsci multiplechoice search tabulate runmigrations canondatecode choose_shutterspeed);
 
 =head2 prompt
 
@@ -2209,6 +2209,10 @@ Display multi-column SQL views as tabulated data.
 
 =item * C<$view> name of SQL view to print
 
+=item * C<$cols> columns of view to return. Defaults to C<*>
+
+=item * C<$where> optional WHERE clause
+
 =head4 Returns
 
 Number of rows displayed
@@ -2219,16 +2223,18 @@ sub tabulate {
 	my $href = shift;
 	my $db = $href->{db};
 	my $view = $href->{view};
+	my $cols = $href->{cols} // '*';
+	my $where = $href->{where} // {};
 
 	# Use SQL::Abstract
 	my $sql = SQL::Abstract->new;
-	my($stmt, @bind) = $sql->select($view);
+	my($stmt, @bind) = $sql->select($view, $cols, $where);
 
 	my $sth = $db->prepare($stmt);
 	my $rows = $sth->execute(@bind);
-	my $cols = $sth->{'NAME'};
+	my $returnedcols = $sth->{'NAME'};
 	my @array;
-	my $table = Text::TabularDisplay->new(@$cols);
+	my $table = Text::TabularDisplay->new(@$returnedcols);
 	while (my @row = $sth->fetchrow) {
 		$table->add(@row);
 	}
@@ -2346,5 +2352,52 @@ sub canondatecode {
 	return;
 }
 
+=head2 choose_shutterspeed
+
+While entering a negative into a film, prompt the user to select an available shutter speed for the camera in use. If they choose C<B> or C<T>, prompt them for
+the duration in seconds, and return that instead. Also add it to the C<SHUTTER_SPEED_AVAILABLE> table, marked as a "bulb" speed if necessary.
+
+=head4 Usage
+
+    my $shutter_speed = &choose_shutterspeed({db=>$db, film_id=>$film_id});
+
+=head4 Arguments
+
+=item * C<$db> DB handle
+
+=item * C<$film_id> Film ID that we are inserting into, so the camera can be found
+
+=head4 Returns
+
+String representation of a shutter speed, which is both a valid EXIF representation, and also a valid data object.
+
+=cut
+
+sub choose_shutterspeed {
+	my $href = shift;
+	my $db = $href->{db};
+	my $film_id = $href->{film_id};
+
+	# Prompt user to choose available shutter speed for their camera
+	my $shutter_speed = &listchoices({db=>$db, keyword=>'shutter speed', table=>'choose_shutter_speed_by_film', where=>{film_id=>$film_id}, type=>'text', required=>1});
+
+	# If they chose B or T
+	if ($shutter_speed eq 'B' or $shutter_speed eq 'T') {
+		my $shutter_speed = &prompt({prompt=>'What duration was the exposure? (s)', type=>'integer', required=>1});
+
+		# If this is not already a valid shutter speed, insert it as a bulb-only speed
+		my $cameramodel_id = &lookupval({db=>$db, col=>'cameramodel_id', table=>'FILM join CAMERA on FILM.camera_id=CAMERA.camera_id', where=>{film_id=>$film_id}});
+		if (!&lookupval({db=>$db, col=>'count(*)', table=>'SHUTTER_SPEED_AVAILABLE', where=>{cameramodel_id=>$cameramodel_id, shutter_speed=>$shutter_speed}})) {
+			# insert new bulb shutter speed
+			my %data;
+			$data{cameramodel_id} = $cameramodel_id;
+			$data{shutter_speed} = $shutter_speed;
+			$data{bulb} = 1;
+			&newrecord({db=>$db, data=>\%data, table=>'SHUTTER_SPEED_AVAILABLE', silent=>1});
+		}
+	}
+	return $shutter_speed;
+}
+
 # This ensures the lib loads smoothly
 1;
